diff --git a/lisainstrument/fixed_shift_numpy.py b/lisainstrument/fixed_shift_numpy.py
index e0b1a9e43eb97a557fc489ee2741da64060091be..25a0868f16a6ffdefbc126a8197aade9443d4612 100644
--- a/lisainstrument/fixed_shift_numpy.py
+++ b/lisainstrument/fixed_shift_numpy.py
@@ -1,8 +1,8 @@
-"""Functions for interpolating numpy arrays with 1D  regularly spaced data
+"""Functions for applying fixed real-valued shifts to numpy arrays using Lagrange interpolation
 
-This provides a generic interface RegularInterpolator as well as two interpolation
-methods, linear and Lagrange. The latter is written from scratch, see module
-regular_interpolator_dsp for another one based on the dsp.timeshift Lagrange interpolator.
+This provides a generic interface FixedShiftCore as well as an implementation using
+Lagrange interpolation. The latter is written from scratch, see module
+fixed_shift_dsp for another one based on the dsp.timeshift Lagrange interpolator.
 """
 
 from __future__ import annotations
diff --git a/lisainstrument/fixed_shift_dask.py b/lisainstrument/fixed_shift_dask.py
index 7dcc27711dc801c40a51fe261ad940642ff87f6e..7ceea69af10bb7dc954f3d233c88623cc8a1a38b 100644
--- a/lisainstrument/fixed_shift_dask.py
+++ b/lisainstrument/fixed_shift_dask.py
@@ -1,6 +1,6 @@
 """Functions for applying dynamic real-valued shifts to dask arrays using Lagrange interpolation
 
-Use make_dynamic_shift_lagrange_dask to create a Lagrange interpolator for dask arrays.
+Use make_fixed_shift_lagrange_dask to create a Lagrange interpolator for dask arrays.
 """
 
 from __future__ import annotations
@@ -1,6 +1,6 @@
-"""Functions for applying dynamic real-valued shifts to dask arrays using Lagrange interpolation
+"""Functions for applying fixed real-valued shifts to dask arrays using Lagrange interpolation
 